update_service: s/update/image

Not all firmware is updateable, rename it to make sense.

Tested:

"Description": "ME image"

Change-Id: I7f78032726e9e102e9626ae1c788b7be30db2651
Signed-off-by: James Feist <james.feist@linux.intel.com>
diff --git a/redfish-core/lib/update_service.hpp b/redfish-core/lib/update_service.hpp
index 93be08c..9e72fa7 100644
--- a/redfish-core/lib/update_service.hpp
+++ b/redfish-core/lib/update_service.hpp
@@ -677,7 +677,7 @@
 
                             // swInvPurpose is of format:
                             // xyz.openbmc_project.Software.Version.VersionPurpose.ABC
                             // Translate this to "ABC update"
                             size_t endDesc = swInvPurpose->rfind(".");
                             if (endDesc == std::string::npos)
                             {
@@ -694,7 +694,7 @@
                             std::string formatDesc =
                                 swInvPurpose->substr(endDesc);
                             asyncResp->res.jsonValue["Description"] =
-                                formatDesc + " update";
+                                formatDesc + " image";
                             getRelatedItems(asyncResp, *swInvPurpose);
                         },
                         obj.second[0].first, obj.first,
@@ -677,7 +677,7 @@
                             // swInvPurpose is of format:
                             // xyz.openbmc_project.Software.Version.VersionPurpose.ABC
-                            // Translate this to "ABC update"
+                            // Translate this to "ABC image"
                             size_t endDesc = swInvPurpose->rfind(".");
                             if (endDesc == std::string::npos)